@@ -24,6 +24,10 @@ $Id: ReportBuilder.py 24737 2005-08-31 09:00:16Z bdelbosc $
 
 USAGE = """%prog [options] xmlfile
 
+or
+
+  %prog --diff REPORT_PATH1 REPORT_PATH2
+
 %prog analyze a FunkLoad bench xml result file and output a report.
 
 See http://funkload.nuxeo.org/ for more information.
@@ -34,6 +38,9 @@ Examples
                         ReST rendering into stdout.
   %prog --html -o /tmp funkload.xml
                         Build an HTML report in /tmp.
+  %prog --diff /tmp/test_reader-20080101 /tmp/test_reader-20080102
+                        Build a differential report to compare 2 bench reports,
+                        requires gnuplot.
   %prog -h
                         More options.
 """
@@ -43,7 +50,9 @@ from optparse import OptionParser, TitledHelpFormatter
 
 from ReportStats import AllResponseStat, PageStat, ResponseStat, TestStat
 from ReportStats import MonitorStat, ErrorStat
-from ReportRenderer import RenderRst, RenderHtml
+from ReportRenderRst import RenderRst
+from ReportRenderHtml import RenderHtml
+from ReportRenderDiff import RenderDiff
 from utils import trace, get_version
 
 
@@ -196,30 +205,42 @@ def main():
     parser.add_option("--no-percentiles", action="store_false",
                       dest="with_percentiles",
                       help=("No percentiles in tables display min, "
-                            "avg and max in charts."))
+                            "avg and max in charts (gdchart only)."))
     cur_path = os.path.abspath(os.path.curdir)
+    parser.add_option("-d", "--diff", action="store_true",
+                      default=False, dest="diffreport",
+                      help=("Create differential report."))
     parser.add_option("-o", "--output-directory", type="string",
                       dest="output_dir",
-                      help="Directory to store reports.",
+                      help="Parent directory to store reports.",
                       default=cur_path)
 
     options, args = parser.parse_args()
-    if len(args) != 1:
-        parser.error("incorrect number of arguments")
-    options.xml_file = args[0]
-    xml_parser = FunkLoadXmlParser()
-    xml_parser.parse(options.xml_file)
-    if options.html:
-        trace("Creating html report: ...")
-        html_path = RenderHtml(xml_parser.config, xml_parser.stats,
-                               xml_parser.error, xml_parser.monitor,
-                               options)()
+    if options.diffreport:
+        if len(args) != 2:
+            parser.error("incorrect number of arguments")
+        trace("Creating diff report ...")
+        output_dir = options.output_dir
+        html_path = RenderDiff(args[0], args[1], output_dir)
         trace("done: \n")
         trace("file://%s\n" % html_path)
     else:
-        print str(RenderRst(xml_parser.config, xml_parser.stats,
-                            xml_parser.error, xml_parser.monitor,
-                            options))
+        if len(args) != 1:
+            parser.error("incorrect number of arguments")
+        options.xml_file = args[0]
+        xml_parser = FunkLoadXmlParser()
+        xml_parser.parse(options.xml_file)
+        if options.html:
+            trace("Creating html report: ...")
+            html_path = RenderHtml(xml_parser.config, xml_parser.stats,
+                                   xml_parser.error, xml_parser.monitor,
+                                   options)()
+            trace("done: \n")
+            trace("file://%s\n" % html_path)
+        else:
+            print str(RenderRst(xml_parser.config, xml_parser.stats,
+                                xml_parser.error, xml_parser.monitor,
+                                options))
 
 
 if __name__ == '__main__':
